#
# opal_config.mak
#
# Make symbols include file for Open Phone Abstraction library
#
# Copyright (c) 2001 Equivalence Pty. Ltd.
#
# The contents of this file are subject to the Mozilla Public License
# Version 1.0 (the "License"); you may not use this file except in
# compliance with the License. You may obtain a copy of the License at
# http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS"
# basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
# the License for the specific language governing rights and limitations
# under the License.
#
# The Original Code is Open Phone Abstraction library.
#
# The Initial Developer of the Original Code is Equivalence Pty. Ltd.
#
# Contributor(s): ______________________________________.
#

OPAL_MAJOR :=3
OPAL_MINOR :=18
OPAL_STAGE :=.
OPAL_PATCH :=6
OPAL_OEM   :=0

# detected platform
target_cpu       := x86_64
target_os        := linux
target           := linux_x86_64

# The install directories
ifndef prefix
  prefix := /usr
endif
ifndef exec_prefix
  exec_prefix := /usr
endif
ifndef libdir
  libdir := /usr/libx32
endif
ifndef includedir
  includedir := /usr/include
endif
ifndef datarootdir
  datarootdir := ${prefix}/share
endif

OPAL_PLUGIN_DIR  := ${libdir}/opal-3.18.6

# Tool names detected by configure
CC               := x86_64-pld-linux-gnux32-gcc
CXX              := x86_64-pld-linux-gnux32-g++
LD               := x86_64-pld-linux-gnux32-g++
AR               := ar
RANLIB           := ranlib
LN_S             := ln -s
MKDIR_P          := mkdir -p
INSTALL          := /usr/bin/install -c -C
SVN              := /usr/bin/svn
SWIG             := /usr/bin/swig

# Compile/tool flags
CPPFLAGS         :=   -Wall -Wno-unknown-pragmas  -I${includedir}/opal $(CPPFLAGS)
CXXFLAGS         := -Wno-overloaded-virtual -fno-omit-frame-pointer -O2 -fwrapv -pipe -Wformat -Werror=format-security -gdwarf-4 -fno-debug-types-section -fvar-tracking-assignments -g2 -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong --param=ssp-buffer-size=4 -Werror=trampolines -fPIC -mtune=generic -march=x86-64 -gdwarf-4 -fno-debug-types-section -fvar-tracking-assignments -g2  -Wno-deprecated-declarations $(CXXFLAGS)
CFLAGS           := -fno-omit-frame-pointer -O2 -fwrapv -pipe -Wformat -Werror=format-security -gdwarf-4 -fno-debug-types-section -fvar-tracking-assignments -g2 -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong --param=ssp-buffer-size=4 -Werror=trampolines -fPIC -mtune=generic -march=x86-64 -gdwarf-4 -fno-debug-types-section -fvar-tracking-assignments -g2  $(CFLAGS)
LDFLAGS          := -rdynamic -Wl,--as-needed -Wl,--no-copy-dt-needed-entries -Wl,-z,relro -Wl,-z,combreloc  $(LDFLAGS)
LIBS             := -lspeexdsp -lsrtp2 -lcrypto -lz -ldl -pthread  $(LIBS)
SHARED_CPPFLAGS  := -fPIC
SHARED_LDFLAGS    = -shared -Wl,--build-id,-soname,$(LIB_SONAME)
DEBUG_CPPFLAGS   := -D_DEBUG 
DEBUG_CFLAGS     := -gdwarf-4 
OPT_CPPFLAGS     := -DNDEBUG 
OPT_CFLAGS       := -O2 
ARFLAGS          := rc

SHAREDLIBEXT     := so
STATICLIBEXT     := a

# Configuration options
OPAL_PLUGINS     := yes
OPAL_SAMPLES     := no

OPAL_H323        := yes
OPAL_SDP         := yes
OPAL_SIP         := yes
OPAL_IAX2        := yes
OPAL_SKINNY      := yes
OPAL_VIDEO       := yes
OPAL_ZRTP        := no
OPAL_LID         := yes
OPAL_CAPI        := no
OPAL_DAHDI       := no
OPAL_IVR         := yes
OPAL_HAS_H224    := yes
OPAL_HAS_H281    := yes
OPAL_H235_6      := yes
OPAL_H235_8      := yes
OPAL_H450        := yes
OPAL_H460        := yes
OPAL_H501        := yes
OPAL_T120DATA    := no
OPAL_SRTP        := yes
SRTP_SYSTEM      := yes
OPAL_RFC4175     := yes
OPAL_RFC2435     := no
OPAL_AEC         := yes
OPAL_G711PLC     := yes
OPAL_T38_CAP     := yes
OPAL_FAX         := yes
OPAL_JAVA        := no
SPEEXDSP_SYSTEM  := yes
OPAL_HAS_PRESENCE:= yes
OPAL_HAS_MSRP    := yes
OPAL_HAS_SIPIM   := yes
OPAL_HAS_RFC4103 := yes
OPAL_HAS_MIXER   := yes
OPAL_HAS_PCSS    := yes

# PTLib interlocks
OPAL_PTLIB_SSL          := yes
OPAL_PTLIB_SSL_AES      := yes
OPAL_PTLIB_ASN          := yes
OPAL_PTLIB_EXPAT        := yes
OPAL_PTLIB_AUDIO        := yes
OPAL_PTLIB_VIDEO        := yes
OPAL_PTLIB_WAVFILE      := yes
OPAL_PTLIB_DTMF         := yes
OPAL_PTLIB_IPV6         := yes
OPAL_PTLIB_DNS_RESOLVER := yes
OPAL_PTLIB_LDAP         := yes
OPAL_PTLIB_VXML         := yes
OPAL_PTLIB_CONFIG_FILE  := yes
OPAL_PTLIB_HTTPSVC      := yes
OPAL_PTLIB_STUN         := yes
OPAL_PTLIB_CLI          := yes
OPAL_GSTREAMER          := yes

PTLIB_MAKE_DIR   := /usr/share/ptlib/make
PTLIB_LIB_DIR    := /usr/libx32


# Remember where this make file is, it is the platform specific one and there
# is a corresponding platform specific include file that goes with it
OPAL_PLATFORM_INC_DIR := $(abspath $(dir $(lastword $(MAKEFILE_LIST)))../include)


# End of file
